==> visier_api_data_in-0.99201.1793.tar.gz: visier_api_data_in-0.99201.1793/test/test_data_in_push_data_response.py <==
# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_data_in.models
from visier_api_data_in.models.data_in_push_data_response import DataInPushDataResponse

class TestDataInPushDataResponse(unittest.TestCase):
    """DataInPushDataResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataInPushDataResponse:
        """Test DataInPushDataResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return DataInPushDataResponse(
                message = '',
                sequence = 56,
                status = '',
                tenants = [
                    visier_api_data_in.models.data_in/tenant.data_in.Tenant(
                        sources = [
                            visier_api_data_in.models.data_in/source.data_in.Source(
                                data_size = '', 
                                message = '', 
                                rows = '', 
                                source_id = '', 
                                source_name = '', 
                                status = '', )
                            ], 
                        status = '', 
                        tenant_code = '', )
                    ],
                transfer_session_id = ''
            )
        else:
            return DataInPushDataResponse(
        )

    def testDataInPushDataResponse(self):
        """Test DataInPushDataResponse"""
        def validate_instance(instance):
            DataInPushDataResponse.model_validate(inst_req_only)
            instance_deserialized = DataInPushDataResponse.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()

==> visier_api_data_in-0.99201.1876b1.tar.gz: visier_api_data_in-0.99201.1876b1/test/test_data_in_push_data_response.py <==
# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1876
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_data_in.models
from visier_api_data_in.models.data_in_push_data_response import DataInPushDataResponse

class TestDataInPushDataResponse(unittest.TestCase):
    """DataInPushDataResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataInPushDataResponse:
        """Test DataInPushDataResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return DataInPushDataResponse(
                transfer_session_id = '',
                sequence = 56,
                status = '',
                message = '',
                tenants = [
                    visier_api_data_in.models.data_in/tenant.data_in.Tenant(
                        tenant_code = '', 
                        status = '', 
                        sources = [
                            visier_api_data_in.models.data_in/source.data_in.Source(
                                source_id = '', 
                                source_name = '', 
                                data_size = '', 
                                rows = '', 
                                status = '', 
                                message = '', )
                            ], )
                    ]
            )
        else:
            return DataInPushDataResponse(
        )

    def testDataInPushDataResponse(self):
        """Test DataInPushDataResponse"""
        def validate_instance(instance):
            DataInPushDataResponse.model_validate(inst_req_only)
            instance_deserialized = DataInPushDataResponse.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()
